Learn R Programming

Certara.RsNLME.ModelBuilder (version 3.0.1)

change_ThetasMmdl: Passes the metamodel to estimatesUI and, after returning, saves it as a metamodel file

Description

Passes the metamodel to estimatesUI and, after returning, saves it as a metamodel file

Usage

change_ThetasMmdl(metamodelFile)

Value

changed metamodel text

Arguments

metamodelFile

File where the metamodel should be updated

Examples

Run this code
if (interactive()) {
  OneCpt_IVInfusionFile <- system.file("vignettesdata/OneCpt_IVInfusion.mmdl",
  package = "Certara.RsNLME",
  mustWork = TRUE)
  
  change_ThetasMmdl(OneCpt_IVInfusionFile)
}

Run the code above in your browser using DataLab