Learn R Programming

Certara.RsNLME.ModelBuilder (version 3.0.1)

create_metamodelBuiltin: Run modelBuilderUI() and create resulting metamodel

Description

Used by Pirana to run modelBuilderUI(), saving the resulting metamodel e.g., .mmmdl file given model building operations performed in GUI.

Usage

create_metamodelBuiltin(metamodelFile, datafile, author = "")

Value

NLME PML model S4 class instance

Arguments

metamodelFile

File where the metamodel should be created.

datafile

File with input data.

author

Optional character string to specify the author in the metamodel.

Examples

Run this code
if (interactive()) {
tmp_data <- tempfile(fileext = ".csv")
write.csv(Certara.RsNLME::pkData, tmp_data, row.names = FALSE)

create_metamodelBuiltin(
  "run1.mmdl",
  tmp_data
  )
}

Run the code above in your browser using DataLab