Learn R Programming

Certara.RsNLME.ModelBuilder (version 3.0.1)

create_metamodelTextual: Send metamodel to modelTextualUI() and run shiny application

Description

Used by Pirana to send existing metamodel to modelTextualUI() for editing, and after returning, saves it as a metamodel file e.g, .mmdl.

Usage

create_metamodelTextual(metamodelFile)

Value

Updated metamodel text.

Arguments

metamodelFile

Path to existing metmodel file.

Details

If DOSING CYCLE block is presented in the metamodel, it will be transferred to COLDEF block with a warning.

Examples

Run this code
if (interactive()) {
mmdl_file <- system.file("vignettesdata/OneCpt_IVInfusion.mmdl",
  package = "Certara.RsNLME")

create_metamodelTextual(
  mmdl_file
  )
}

Run the code above in your browser using DataLab