Learn R Programming

Certara.RsNLME.ModelBuilder (version 3.0.1)

modelBuilderUI: Build RsNLME model from Shiny GUI and generate corresponding RsNLME code

Description

Shiny application to build RsNLME model from Shiny GUI and generate corresponding RsNLME code based on input selections.

Usage

modelBuilderUI(
  data,
  modelName = "PKPDmodel",
  workingDir = "",
  baseModel = NULL
)

Value

A model object of class NlmePmlModel

Arguments

data

Input dataset.

modelName

Name of the model; if missing, named as 'PKPDmodel.'

workingDir

Working directory to run the model. Current working directory will be used if workingDir not specified or does not exist.

baseModel

The model object from where the input dataset and model name are recovered if arguments data and modelName are not specified.

Examples

Run this code
if (interactive()) {
model <- modelBuilderUI(data = Certara.RsNLME::pkData, modelName = "PK_Model")
}
 

Run the code above in your browser using DataLab