powered by
modelBuilderUI()
Used by Pirana to run modelBuilderUI(), saving the resulting metamodel e.g., .mmmdl file given model building operations performed in GUI.
create_metamodelBuiltin(metamodelFile, datafile, author = "")
NLME PML model S4 class instance
File where the metamodel should be created.
File with input data.
Optional character string to specify the author in the metamodel.
if (interactive()) { tmp_data <- tempfile(fileext = ".csv") write.csv(Certara.RsNLME::pkData, tmp_data, row.names = FALSE) create_metamodelBuiltin( "run1.mmdl", tmp_data ) }
Run the code above in your browser using DataLab