powered by
Shiny application to build RsNLME model from Shiny GUI and generate corresponding RsNLME code based on input selections.
modelBuilderUI( data, modelName = "PKPDmodel", workingDir = "", baseModel = NULL )
A model object of class NlmePmlModel
NlmePmlModel
Input dataset.
Name of the model; if missing, named as 'PKPDmodel.'
missing
Working directory to run the model. Current working directory will be used if workingDir not specified or does not exist.
workingDir
The model object from where the input dataset and model name are recovered if arguments data and modelName are not specified.
data
modelName
if (interactive()) { model <- modelBuilderUI(data = Certara.RsNLME::pkData, modelName = "PK_Model") }
Run the code above in your browser using DataLab